include/pngtile.h
changeset 80 f2f3dba2174c
parent 69 1d188aa94aee
child 86 d4a62899587f
--- a/include/pngtile.h	Mon Jan 25 04:07:09 2010 +0200
+++ b/include/pngtile.h	Mon Jan 25 04:07:22 2010 +0200
@@ -23,7 +23,10 @@
 
 /** Bitmask for pt_image_open modes */
 enum pt_open_mode {
-    /** Update cache if needed */
+    /** Open cache for read*/
+    PT_OPEN_READ    = 0x00,
+
+    /** Open cache for update */
     PT_OPEN_UPDATE   = 0x01,
 
     /** Accept stale cache */